@@ -1,38 +1,11 @@
 # ABSTRACT: 小说打包引擎
-
-=pod
-
-=encoding utf8
-
-=head1 支持输出类型
-
-    txt  : txt形式的小说
-
-    html : 网页形式的小说
-
-    wordpress : 将小说发布到WordPress空间
-
-=head1 FUNCTION
-
-=head2 new 初始化解析模块
-
-   my $packer = Novel::Robot::Packer->new(type => 'html');
-
-=head2 打包文件
-   
-   my $ret = $self->main($book_ref, 
-       with_toc => 1, 
-   );
-
-=cut
-
 package  Novel::Robot::Packer;
 use strict;
 use warnings;
 use Encode::Locale;
 use Encode;
 
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 sub new {
     my ( $self, %opt ) = @_;
@@ -42,7 +15,7 @@ sub new {
     bless {%opt}, $module;
 }
 
-sub format_book_output {
+sub format_item_output {
     my ( $self, $bk, $o ) = @_;
     if ( ! $o->{output} ) {
         my $html = '';
